@@ -26,7 +26,7 @@ class DatePicker(BeakerxDOMWidget):
         if value is not None:
             kwargs['value'] = value
         super(DatePicker, self).__init__(**kwargs)
-    
+
     _view_name = Unicode('DatePickerView').tag(sync=True)
     _model_name = Unicode('DatePickerModel').tag(sync=True)
     showTime = Bool(default_value=False,
@@ -38,7 +38,7 @@ class DatePicker(BeakerxDOMWidget):
 class SelectMultipleWithRows(SelectMultiple):
     def __init__(self, **kwargs):
         super(SelectMultipleWithRows, self).__init__(**kwargs)
-    
+
     _view_module = Unicode('beakerx').tag(sync=True)
     _model_module = Unicode('beakerx').tag(sync=True)
     size = Int(5, help="The number of rows to display.").tag(sync=True)
@@ -47,7 +47,7 @@ class SelectMultipleWithRows(SelectMultiple):
 class SelectMultipleSingle(Select):
     def __init__(self, **kwargs):
         super(SelectMultipleSingle, self).__init__(**kwargs)
-    
+
     _view_name = Unicode('SelectMultipleSingleView').tag(sync=True)
     _model_name = Unicode('SelectMultipleSingleModel').tag(sync=True)
     _view_module = Unicode('beakerx').tag(sync=True)
@@ -55,25 +55,6 @@ class SelectMultipleSingle(Select):
     size = Int(5, help="The number of rows to display.").tag(sync=True)
 
 
-class ComboBox(Dropdown):
-    def __init__(self, **kwargs):
-        super(ComboBox, self).__init__(**kwargs)
-    
-    _view_name = Unicode('ComboBoxView').tag(sync=True)
-    _model_name = Unicode('ComboBoxModel').tag(sync=True)
-    _view_module = Unicode('beakerx').tag(sync=True)
-    _model_module = Unicode('beakerx').tag(sync=True)
-    editable = Bool(default_value=False).tag(sync=True)
-    original_options = Union([List(), Dict()])
-    
-    def _handle_msg(self, msg):
-        if 'value' in msg['content']['data']['sync_data']:
-            if msg['content']['data']['sync_data']['value'] not in self.options:
-                self.options = self.original_options[:]
-                self.options += (msg['content']['data']['sync_data']['value'],)
-        super(ComboBox, self)._handle_msg(msg)
-
-
 class EasyForm(BeakerxBox):
     _view_name = Unicode('EasyFormView').tag(sync=True)
     _model_name = Unicode('EasyFormModel').tag(sync=True)
@@ -81,38 +62,40 @@ class EasyForm(BeakerxBox):
     test = ""
     HORIZONTAL = 1
     VERTICAL = 2
-    
+    components = dict()
+
     def __init__(self, *args, **kwargs):
         super(EasyForm, self).__init__(**kwargs)
         self.easyFormName = getValue(kwargs, 'title', "")
         if self.easyFormName == "" and len(args) > 0:
             self.easyFormName = args[0]
-    
+
     def _handle_msg(self, msg):
         print(msg)
-    
+
     def addTextField(self, *args, **kwargs):
         text = BeakerxText(description=self.getDescription(args, kwargs))
         text.size = getValue(kwargs, 'width', -1)
         self.children += (text,)
+        self.components[text.description] = text
         return text
-    
+
     def addTextArea(self, *args, **kwargs):
         textarea = BeakerxTextArea(
-                description=self.getDescription(args, kwargs))
+            description=self.getDescription(args, kwargs))
         textarea.cols = getValue(kwargs, 'width', -1)
         textarea.rows = getValue(kwargs, 'height', -1)
         self.children += (textarea,)
+        self.components[textarea.description] = textarea
         return textarea
-    
+
     def addButton(self, *args, **kwargs):
         button = BeakerxButton(description=self.getDescription(args, kwargs))
         button.tag = getValue(kwargs, 'tag', "")
         button.on_click(self.buttonCallback)
         self.children += (button,)
-        
         return button
-    
+
     def buttonCallback(self, *args):
         if len(args) > 0:
             args[0].actionPerformed()
@@ -121,42 +104,43 @@ class EasyForm(BeakerxBox):
             msg = {'runByTag': args[0].tag}
             state = {'state': msg}
             comm.send(data=state, buffers=[])
-    
+
     def addList(self, *args, **kwargs):
         multi_select = getValue(kwargs, 'multi', True)
         if multi_select:
             list = SelectMultipleWithRows(
-                    description=self.getDescription(args, kwargs))
+                description=self.getDescription(args, kwargs))
         else:
             list = SelectMultipleSingle(
-                    description=self.getDescription(args, kwargs))
+                description=self.getDescription(args, kwargs))
         list.options = self.getOptions(args, kwargs)
         list.size = getValue(kwargs, 'rows', 2)
-        
+
         self.children += (list,)
-        
+        self.components[list.description] = list
         return list
-    
+
     def addDatePicker(self, *args, **kwargs):
         data_picker = DatePicker(description=self.getDescription(args, kwargs))
         self.children += (data_picker,)
-        
+        self.components[data_picker.description] = data_picker
         return data_picker
-    
+
     def addComboBox(self, *args, **kwargs):
-        dropdown = ComboBox(description=self.getDescription(args, kwargs))
+        dropdown = BeakerxComboBox(description=self.getDescription(args, kwargs))
         dropdown.options = self.getOptions(args, kwargs)
         dropdown.original_options = self.getOptions(args, kwargs)
         dropdown.editable = getValue(kwargs, 'editable', False)
         self.children += (dropdown,)
-        
+        self.components[dropdown.description] = dropdown
         return dropdown
-    
+
     def addCheckBox(self, *args, **kwargs):
         checkbox = BeakerxCheckbox(description=self.getDescription(args, kwargs))
         self.children += (checkbox,)
+        self.components[checkbox.description] = checkbox
         return checkbox
-    
+
     def addCheckBoxes(self, *args, **kwargs):
         layout = BeakerxHBox()
         orientation = getValue(kwargs, 'orientation', 2)
@@ -164,16 +148,18 @@ class EasyForm(BeakerxBox):
             box = BeakerxHBox()
         else:
             box = BeakerxVBox()
-        
+        checkbox = BeakerxCheckboxGroup()
+
         for checkBoxItem in self.getOptions(args, kwargs):
-            checkbox = BeakerxCheckbox(description=checkBoxItem)
-            box.children += (checkbox,)
-            
+            children = BeakerxCheckbox(description=checkBoxItem)
+            checkbox.addChildren(children)
+            box.children += (children,)
+
         layout.children += (BeakerxLabel(value=self.getDescription(args, kwargs)), box,)
         self.children += (layout,)
-        
+        self.components[self.getDescription(args, kwargs)] = checkbox
         return layout
-    
+
     def addRadioButtons(self, *args, **kwargs):
         orientation = getValue(kwargs, 'orientation', EasyForm.VERTICAL)
         radio_buttons = RadioButtons(options=self.getOptions(args, kwargs),
@@ -186,36 +172,34 @@ class EasyForm(BeakerxBox):
             box = BeakerxHBox()
             box.children += (radio_buttons,)
             self.children += (box,)
-        
+        self.components[radio_buttons.description] = radio_buttons
         return radio_buttons
-    
-    def keySet(self):
-        return self.children
-    
+
+    def __iter__(self):
+        return iter(self.components)
+
     def __getitem__(self, key):
         return self.get(key)
-    
+
     def __setitem__(self, key, value):
         self.put(key, value)
-    
+
     def get(self, key):
-        for child in self.children:
-            if child.description == key:
-                return child.value
-    
+        if key in self.components:
+            return self.components[key].value
+        else:
+            return ""
+
     def put(self, key, value):
-        for child in self.children:
-            if child.description == key:
-                child.value = value
-                break
-    
+        self.components[key].value = value
+
     @staticmethod
     def getDescription(args, kwargs):
         if len(args) > 0:
             return args[0]
         else:
             return getValue(kwargs, 'description', "")
-    
+
     @staticmethod
     def getOptions(args, kwargs):
         if len(args) > 1:
