@@ -18,45 +18,23 @@ from beakerx.utils import *
 from beakerx.tabledisplay.tableitems import *
 import math
 import numpy
+from pandas import DataFrame
+
+
 class Table(BaseObject):
     def __init__(self, *args, **kwargs):
-        self.columnNames = args[0].columns.tolist()
+
         self.values = []
         self.types = []
         types_map = dict()
-        for column in self.columnNames:
-            column_type = self.convertType(args[0].dtypes[column].name,
-                             args[0][column][0])
-            self.types.append(column_type)
-            types_map[column] = column_type
+        self.columnNames = []
+        if isinstance(args[0], DataFrame):
+            self.convert_from_pandas(args, types_map)
+        elif isinstance(args[0], dict):
+            self.convert_from_dict(args)
+        elif isinstance(args[0], list):
+            self.convert_from_list(args, types_map)
 
-        for ix in range(len(args[0])):
-            row = []
-            for columnName in self.columnNames:
-                value = args[0][columnName][ix]
-                value_type = types_map.get(columnName)
-               
-                if value_type == "time":
-                    row.append(DateType(value))
-                elif value_type == "double":
-                    row.append(value.astype('str'))
-                elif value_type == "integer":
-                    row.append(value.item())
-                elif value_type == "int64":
-                    row.append(value.astype('str'))
-                elif value_type == "string":
-                    if isinstance(value, float):
-                        if math.isnan(value):
-                            row.append("")
-                        else:
-                            row.append(str(value))
-                    else:
-                        row.append(str(value))
-                        
-                else:
-                    row.append(str(value))
-            self.values.append(row)
-        
         self.headersVertical = False
         self.hasIndex = None
         self.headerFontSize = None
@@ -83,8 +61,73 @@ class Table(BaseObject):
         self.columnsFrozenRight = {}
         self.columnsVisible = {}
         self.hasDoubleClickAction = False
-    
-    def convertType(self, object_type, value):
+
+    def convert_from_dict(self, args):
+        self.columnNames.append("Key")
+        self.columnNames.append("Value")
+        for key in args[0].keys():
+            row = [key, args[0].get(key, "")]
+            self.values.append(row)
+
+    def convert_from_list(self, args, types_map):
+        for element in args[0]:
+            for key in element.keys():
+                if key not in self.columnNames:
+                    self.columnNames.append(key)
+                    column_type = self.convert_type(type(element[key]), element[key])
+                    self.types.append(column_type)
+                    types_map[key] = column_type
+
+        for element in args[0]:
+            row = []
+            for columnName in self.columnNames:
+                value = element.get(columnName, "")
+                value_type = types_map.get(columnName)
+
+                row.append(self.convert_value(value, value_type))
+            self.values.append(row)
+
+    def convert_from_pandas(self, args, types_map):
+        self.columnNames = args[0].columns.tolist()
+        for column in self.columnNames:
+            column_type = self.convert_type(args[0].dtypes[column].name,
+                                            args[0][column][0])
+            self.types.append(column_type)
+            types_map[column] = column_type
+        for index in range(len(args[0])):
+            row = []
+            for columnName in self.columnNames:
+                value = args[0][columnName][index]
+                value_type = types_map.get(columnName)
+
+                row.append(self.convert_value(value, value_type))
+            self.values.append(row)
+
+    @staticmethod
+    def convert_value(value, value_type):
+        if value_type == "time":
+            converted_value = DateType(value)
+        elif value_type == "double":
+            converted_value = value.astype('str')
+        elif value_type == "integer":
+            converted_value = value.item()
+        elif value_type == "int64":
+            converted_value = value.astype('str')
+        elif value_type == "string":
+            if isinstance(value, float):
+                if math.isnan(value):
+                    converted_value = ""
+                else:
+                    converted_value = str(value)
+            else:
+                converted_value = str(value)
+
+        else:
+            converted_value = str(value)
+        return converted_value
+
+    @staticmethod
+    def convert_type(object_type, value):
         if value == "":
             return "string"
         if isinstance(value, float):
@@ -111,73 +154,72 @@ class TableDisplay(BeakerxDOMWidget):
     _view_name = Unicode('TableDisplayView').tag(sync=True)
     _model_name = Unicode('TableDisplayModel').tag(sync=True)
     model = Dict().tag(sync=True)
-    
+
     def __init__(self, *args, **kwargs):
         super(TableDisplay, self).__init__(**kwargs)
         self.chart = Table(*args, **kwargs)
         self.model = self.chart.transform()
-    
+
     def setAlignmentProviderForColumn(self, column_name, display_alignment):
         if isinstance(display_alignment, TableDisplayAlignmentProvider):
             self.chart.alignmentForColumn[column_name] = display_alignment.value
         self.model = self.chart.transform()
         return self
-    
+
     def setStringFormatForTimes(self, time_unit):
         self.chart.stringFormatForTimes = time_unit.name
         self.model = self.chart.transform()
         return self
-    
+
     def setStringFormatForType(self, type, formater):
         if isinstance(type, ColumnType):
             self.chart.stringFormatForType[type.value] = formater
             self.model = self.chart.transform()
             return self
-    
+
     def setStringFormatForColumn(self, column, formater):
         self.chart.stringFormatForColumn[column] = formater
         self.model = self.chart.transform()
         return self
-    
+
     def setRendererForColumn(self, column, renderer):
         self.chart.rendererForColumn[column] = renderer
         self.model = self.chart.transform()
         return self
-    
+
     def setRendererForType(self, type, renderer):
         if isinstance(type, ColumnType):
             self.chart.rendererForType[type.value] = renderer
             self.model = self.chart.transform()
         return self
-    
+
     def setColumnFrozen(self, column, visible):
         self.chart.columnsFrozen[column] = visible
         self.model = self.chart.transform()
         return self
-    
+
     def setColumnFrozenRight(self, column, visible):
         self.chart.columnsFrozenRight[column] = visible
         self.model = self.chart.transform()
         return self
-    
+
     def setColumnVisible(self, column, visible):
         self.chart.columnsVisible[column] = visible
         self.model = self.chart.transform()
         return self
-    
+
     def setColumnOrder(self, order):
         self.chart.columnOrder = order
         self.model = self.chart.transform()
         return self
-    
+
     def removeAllCellHighlighters(self):
         self.chart.cellHighlighters = []
         self.model = self.chart.transform()
         return self
-    
+
     def addCellHighlighter(self, highlighter):
         if isinstance(highlighter, HeatmapHighlighter):
             self.chart.cellHighlighters.append(highlighter)
             self.model = self.chart.transform()
         return self
-        
\ No newline at end of file
